==> clanlib-4.1.0.tar.gz: ClanLib-4.1.0/Sources/GL/GL1/gl1_render_buffer_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
**    Harry Storbacka
*/

#pragma once


#include "gl1_graphic_context_provider.h"
#include "API/Display/TargetProviders/render_buffer_provider.h"

namespace clan
{
	class GL1RenderBufferProvider : public RenderBufferProvider
	{
	public:
		GL1RenderBufferProvider(GL1GraphicContextProvider *gc_provider);
		~GL1RenderBufferProvider();

		GLuint get_handle();
		/// \brief Creates a render buffer image of the specified dimensions.
		virtual void create(int width, int height, TextureFormat texture_format, int multisample_samples) override;
	};
}

==> clanlib-4.2.0.tar.gz: ClanLib-4.2.0/Sources/GL/GL1/gl1_render_buffer_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
**    Harry Storbacka
*/

#pragma once


#include "gl1_graphic_context_provider.h"
#include "API/Display/TargetProviders/render_buffer_provider.h"

namespace clan
{
	class GL1RenderBufferProvider : public RenderBufferProvider
	{
	public:
		GL1RenderBufferProvider(GL1GraphicContextProvider *gc_provider);
		~GL1RenderBufferProvider() override;

		GLuint get_handle();
		/// \brief Creates a render buffer image of the specified dimensions.
		void create(int width, int height, TextureFormat texture_format, int multisample_samples) override;
	};
}
